
[![](https://codecov.io/gh/nickderobertis/data-code/branch/master/graph/badge.svg)](https://codecov.io/gh/nickderobertis/data-code)

# data-code

## Overview

Data pipelines for humans. Work with variables, sources, and pipelines rather than raw data. Also includes high-level tools to analyze, summarize, and transform data.

## Getting Started

Install `datacode`:

```
pip install datacode
```

A simple example:

```python
import datacode

# Do something with datacode
```

## Links

See the
[documentation here.](
https://nickderobertis.github.io/data-code/
)

## Author

Created by Nick DeRobertis. MIT License.
